@@ -1,13 +1,13 @@
-#	Geo::Ellipsoid
+#       Geo::Ellipsoid
 #
-#	This package implements an Ellipsoid class to perform latitude 
-#	and longitude calculations on the surface of an ellipsoid.
+#       This package implements an Ellipsoid class to perform latitude
+#       and longitude calculations on the surface of an ellipsoid.
 #
-#	This is a Perl conversion of existing Fortran code (see
-#	ACKNOWLEDGEMENTS) and the author of this class makes no 
-#	claims of originality. Nor can he even vouch for the 
-#	results of the calculations, although they do seem to 
-#	work for him and have been tested against other methods.
+#       This is a Perl conversion of existing Fortran code (see
+#       ACKNOWLEDGEMENTS) and the author of this class makes no
+#       claims of originality. Nor can he even vouch for the
+#       results of the calculations, although they do seem to
+#       work for him and have been tested against other methods.
 
 package Geo::Ellipsoid;
 
@@ -19,19 +19,23 @@ use Scalar::Util 'looks_like_number';
 use Math::Trig;
 use Carp;
 
+=pod
+
 =head1 NAME
 
 Geo::Ellipsoid - Longitude and latitude calculations using an ellipsoid model.
 
 =head1 VERSION
 
-Version 1.12, released July 4, 2008.
+Version 1.13, released Sep 07, 2016.
 
 =cut
 
-our $VERSION = '1.12';
+our $VERSION = '1.13';
 our $DEBUG = 0;
 
+=pod
+
 =head1 SYNOPSIS
 
   use Geo::Ellipsoid;
@@ -45,11 +49,11 @@ our $DEBUG = 0;
 
 =head1 DESCRIPTION
 
-Geo::Ellipsoid performs geometrical calculations on the surface of 
-an ellipsoid. An ellipsoid is a three-dimension object formed from 
-the rotation of an ellipse about one of its axes. The approximate 
+Geo::Ellipsoid performs geometrical calculations on the surface of
+an ellipsoid. An ellipsoid is a three-dimension object formed from
+the rotation of an ellipse about one of its axes. The approximate
 shape of the earth is an ellipsoid, so Geo::Ellipsoid can accurately
-calculate distance and bearing between two widely-separated locations 
+calculate distance and bearing between two widely-separated locations
 on the earth's surface.
 
 The shape of an ellipsoid is defined by the lengths of its
@@ -57,8 +61,8 @@ semi-major and semi-minor axes. The shape may also be specifed by
 the flattening ratio C<f> as:
 
     f = ( semi-major - semi-minor ) / semi-major
-    
-which, since f is a small number, is normally given as the reciprocal 
+
+which, since f is a small number, is normally given as the reciprocal
 of the flattening C<1/f>.
 
 The shape of the earth has been surveyed and estimated differently
@@ -79,12 +83,12 @@ our $eps = 1.0e-23;
 our $max_loop_count = 20;
 our $twopi = 2 * pi;
 our $halfpi = pi/2;
-our %defaults = ( 
-  ellipsoid => 'WGS84', 
+our %defaults = (
+  ellipsoid => 'WGS84',
   units => 'radians',
-  distance_units => 'meter', 
+  distance_units => 'meter',
   longitude => 0,
-  latitude => 1,	# allows use of _normalize_output
+  latitude => 1,        # allows use of _normalize_output
   bearing => 0,
 );
 our %distance = (
@@ -96,9 +100,9 @@ our %distance = (
 );
 
 # set of ellipsoids that can be used.
-# values are 
-#  1) a = semi-major (equatorial) radius of Ellipsoid 
-#  2) 1/f = reciprocal of flattening (f), the ratio of the semi-minor 
+# values are
+#  1) a = semi-major (equatorial) radius of Ellipsoid
+#  2) 1/f = reciprocal of flattening (f), the ratio of the semi-minor
 #     (polar) radius to the semi-major (equatorial) axis, or
 #     polar radius = equatorial radius * ( 1 - f )
 
@@ -125,28 +129,30 @@ our %ellipsoids = (
     'WGS84'              => [ 6378137.0,   298.257223563   ],
 );
 
+=pod
+
 =head1 CONSTRUCTOR
 
 =head2 new
 
 The new() constructor may be called with a hash list to set the value of the
 ellipsoid to be used, the value of the units to be used for angles and
-distances, and whether or not the output range of longitudes and bearing 
-angles should be symmetric around zero or always greater than zero.  
+distances, and whether or not the output range of longitudes and bearing
+angles should be symmetric around zero or always greater than zero.
 The initial default constructor is equivalent to the following:
 
-    my $geo = Geo::Ellipsoid->new( 
-      ellipsoid => 'WGS84', 
+    my $geo = Geo::Ellipsoid->new(
+      ellipsoid => 'WGS84',
       units => 'radians' ,
       distance_units => 'meter',
       longitude => 0,
       bearing => 0,
     );
-    
+
 The constructor arguments may be of any case and, with the exception of
-the ellipsoid value, abbreviated to their first three characters. 
-Thus, ( UNI => 'DEG', DIS => 'FEE', Lon => 1, ell => 'NAD27', bEA => 0 ) 
-is valid. 
+the ellipsoid value, abbreviated to their first three characters.
+Thus, ( UNI => 'DEG', DIS => 'FEE', Lon => 1, ell => 'NAD27', bEA => 0 )
+is valid.
 
 =cut
 
@@ -155,42 +161,43 @@ sub new
   my( $class, %args ) = @_;
   my $self = {%defaults};
   print "new: @_\n" if $DEBUG;
-  foreach my $key ( keys %args ) {
-    my $val = $args{$key};
+  while (my ($key, $val) = each %args) {
     if( $key =~ /^ell/i ) {
-      $self->{ellipsoid} = uc $args{$key};
+      $self->{ellipsoid} = uc $val;
     }elsif( $key =~ /^uni/i ) {
-      $self->{units} = $args{$key};
+      $self->{units} = $val;
     }elsif( $key =~ /^dis/i ) {
-      $self->{distance_units} = $args{$key};
+      $self->{distance_units} = $val;
     }elsif( $key =~ /^lon/i ) {
-      $self->{longitude} = $args{$key};
+      $self->{longitude} = $val;
     }elsif( $key =~ /^bea/i ) {
-      $self->{bearing} = $args{$key};
+      $self->{bearing} = $val;
     }else{
-      carp("Unknown argument: $key => $args{$key}");
+      carp("Unknown argument: $key => $val");
     }
   }
-  set_units($self,$self->{units});
-  set_ellipsoid($self,$self->{ellipsoid});
-  set_distance_unit($self,$self->{distance_units});
-  set_longitude_symmetric($self,$self->{longitude});
-  set_bearing_symmetric($self,$self->{bearing});
-  print 
+  bless $self, $class;
+  $self->set_ellipsoid($self->{ellipsoid});
+  $self->set_units($self->{units});
+  $self->set_distance_unit($self->{distance_units});
+  $self->set_longitude_symmetric($self->{longitude});
+  $self->set_bearing_symmetric($self->{bearing});
+  print
     "Ellipsoid(units=>$self->{units},distance_units=>" .
     "$self->{distance_units},ellipsoid=>$self->{ellipsoid}," .
     "longitude=>$self->{longitude},bearing=>$self->{bearing})\n" if $DEBUG;
-  bless $self,$class;
   return $self;
 }
 
+=pod
+
 =head1 METHODS
 
 =head2 set_units
 
-Set the angle units used by the Geo::Ellipsoid object. The units may 
-also be set in the constructor of the object. The allowable values are 
-'degrees' or 'radians'. The default is 'radians'. The units value is 
+Set the angle units used by the Geo::Ellipsoid object. The units may
+also be set in the constructor of the object. The allowable values are
+'degrees' or 'radians'. The default is 'radians'. The units value is
 not case sensitive and may be abbreviated to 3 letters. The units of
 angle apply to both input and output latitude, longitude, and bearing
 values.
@@ -214,12 +221,14 @@ sub set_units
   $self->{units} = $units;
 }
 
+=pod
+
 =head2 set_distance_unit
 
 Set the distance unit used by the Geo::Ellipsoid object. The unit of
-distance may also be set in the constructor of the object. The recognized 
-values are 'meter', 'kilometer', 'mile', 'nm' (nautical mile), or 'foot'. 
-The default is 'meter'. The value is not case sensitive and may be 
+distance may also be set in the constructor of the object. The recognized
+values are 'meter', 'kilometer', 'mile', 'nm' (nautical mile), or 'foot'.
+The default is 'meter'. The value is not case sensitive and may be
 abbreviated to 3 letters.
 
     $geo->set_distance_unit('kilometer');
@@ -250,18 +259,18 @@ sub set_distance_unit
   my $conversion = 0;
 
   if( defined $unit ) {
-  
+
     my( $key, $val );
     while( ($key,$val) = each %distance ) {
       my $re = substr($key,0,3);
       print "trying ($key,$re,$val)\n" if $DEBUG;
       if( $unit =~ /^$re/i ) {
         $self->{distance_units} = $unit;
-        $conversion = $val;	
+        $conversion = $val;
 
-	# finish iterating to reset 'each' function call
-	while( each %distance ) {}
-	last;
+        # finish iterating to reset 'each' function call
+        while( each %distance ) {}
+        last;
       }
     }
 
@@ -281,9 +290,11 @@ sub set_distance_unit
   $self->{conversion} = $conversion;
 }
 
+=pod
+
 =head2 set_ellipsoid
 
-Set the ellipsoid to be used by the Geo::Ellipsoid object. See 
+Set the ellipsoid to be used by the Geo::Ellipsoid object. See
 L<"DEFINED ELLIPSOIDS"> below for the allowable values. The value
 may also be set by the constructor. The default value is 'WGS84'.
 
@@ -311,20 +322,22 @@ sub set_ellipsoid
   }else{
     $self->{flattening} = ( 1.0 / $ellipsoids{$ellipsoid}[1]);
     $self->{polar} = $self->{equatorial} * ( 1.0  - $self->{flattening} );
-    $self->{eccentricity} = sqrt( 2.0 * $self->{flattening} - 
+    $self->{eccentricity} = sqrt( 2.0 * $self->{flattening} -
       ( $self->{flattening} * $self->{flattening} ) );
   }
 }
 
+=pod
+
 =head2 set_custom_ellipsoid
 
 Sets the ellipsoid parameters to the specified ( major semiaxis and
 reciprocal flattening. A zero value for the reciprocal flattening
-will result in a sphere for the ellipsoid, and a warning message 
+will result in a sphere for the ellipsoid, and a warning message
 will be issued.
 
     $geo->set_custom_ellipsoid( 'sphere', 6378137, 0 );
-    
+
 =cut
 
 sub set_custom_ellipsoid
@@ -335,17 +348,19 @@ sub set_custom_ellipsoid
   $recip = 0 unless defined $recip;
   if( $major ) {
     $ellipsoids{$name} = [ $major, $recip ];
-  }else{  
+  }else{
     croak("set_custom_ellipsoid called without semi-major radius parameter");
   }
-  set_ellipsoid($self,$name);
+  $self->set_ellipsoid($name);
 }
 
+=pod
+
 =head2 set_longitude_symmetric
 
-If called with no argument or a true argument, sets the range of output 
-values for longitude to be in the range [-pi,+pi) radians.  If called with 
-a false or undefined argument, sets the output angle range to be 
+If called with no argument or a true argument, sets the range of output
+values for longitude to be in the range [-pi,+pi) radians.  If called with
+a false or undefined argument, sets the output angle range to be
 [0,2*pi) radians.
 
     $geo->set_longitude_symmetric(1);
@@ -365,11 +380,13 @@ sub set_longitude_symmetric
   }
 }
 
+=pod
+
 =head2 set_bearing_symmetric
 
-If called with no argument or a true argument, sets the range of output 
-values for bearing to be in the range [-pi,+pi) radians.  If called with 
-a false or undefined argument, sets the output angle range to be 
+If called with no argument or a true argument, sets the range of output
+values for bearing to be in the range [-pi,+pi) radians.  If called with
+a false or undefined argument, sets the output angle range to be
 [0,2*pi) radians.
 
     $geo->set_bearing_symmetric(1);
@@ -389,24 +406,26 @@ sub set_bearing_symmetric
   }
 }
 
+=pod
+
 =head2 set_defaults
 
-Sets the defaults for the new method. Call with key, value pairs similar to 
+Sets the defaults for the new method. Call with key, value pairs similar to
 new.
 
-    $Geo::Ellipsoid->set_defaults( 
-      units => 'degrees', 
+    $Geo::Ellipsoid->set_defaults(
+      units => 'degrees',
       ellipsoid => 'GRS80',
       distance_units => 'kilometer',
       longitude => 1,
       bearing => 0
     );
 
-Keys and string values (except for the ellipsoid identifier) may be shortened 
+Keys and string values (except for the ellipsoid identifier) may be shortened
 to their first three letters and are case-insensitive:
 
-    $Geo::Ellipsoid->set_defaults( 
-      uni => 'deg', 
+    $Geo::Ellipsoid->set_defaults(
+      uni => 'deg',
       ell => 'GRS80',
       dis => 'kil',
       lon => 1,
@@ -419,18 +438,18 @@ sub set_defaults
 {
   my $self = shift;
   my %args = @_;
-  foreach my $key ( keys %args ) {
+  while (my ($key, $val) = each %args) {
     if( $key =~ /^ell/i ) {
-      $defaults{ellipsoid} = uc $args{$key};
+      $defaults{ellipsoid} = uc $val;
     }elsif( $key =~ /^uni/i ) {
-      $defaults{units} = $args{$key};
+      $defaults{units} = $val;
     }elsif( $key =~ /^dis/i ) {
-      $defaults{distance_units} = $args{$key};
+      $defaults{distance_units} = $val;
     }elsif( $key =~ /^lon/i ) {
-      $defaults{longitude} = $args{$key};
+      $defaults{longitude} = $val;
     }elsif( $key =~ /^bea/i ) {
-      $defaults{bearing} = $args{$key};
-    }else{  
+      $defaults{bearing} = $val;
+    }else{
       croak("Geo::Ellipsoid::set_defaults called with invalid key: $key");
     }
   }
@@ -438,16 +457,18 @@ sub set_defaults
     if $DEBUG;
 }
 
+=pod
+
 =head2 scales
 
-Returns a list consisting of the distance unit per angle of latitude 
-and longitude (degrees or radians) at the specified latitude. 
+Returns a list consisting of the distance unit per angle of latitude
+and longitude (degrees or radians) at the specified latitude.
 These values may be used for fast approximations of distance
 calculations in the vicinity of some location.
 
     ( $lat_scale, $lon_scale ) = $geo->scales($lat0);
-    $x = $lon_scale * ($lon - $lon0); 
-    $y = $lat_scale * ($lat - $lat0); 
+    $x = $lon_scale * ($lon - $lon0);
+    $y = $lat_scale * ($lat - $lat0);
 
 =cut
 
@@ -462,7 +483,7 @@ sub scales
     carp("scales() method requires latitude argument; assuming 0");
     $lat = 0;
   }
-  
+
   my $aa = $self->{equatorial};
   my $bb = $self->{polar};
   my $a2 = $aa*$aa;
@@ -474,7 +495,7 @@ sub scales
   my $n1 = $aa * $bb;
   my $latscl = ( $n1 * $n1 ) / ( $d3 * $d4 * $self->{conversion} );
   my $lonscl = ( $aa * $d1 ) / ( $d4 * $self->{conversion} );
-  
+
   if( $DEBUG ) {
     print "lat=$lat, aa=$aa, bb=$bb\nd1=$d1, d2=$d2, d3=$d3, d4=$d4\n";
     print "latscl=$latscl, lonscl=$lonscl\n";
@@ -487,6 +508,8 @@ sub scales
   return ( $latscl, $lonscl );
 }
 
+=pod
+
 =head2 range
 
 Returns the range in distance units between two specified locations given
@@ -496,16 +519,18 @@ as latitude, longitude pairs.
     my $dist = $geo->range( @origin, @destination );
 
 =cut
-    
+
 sub range
 {
   my $self = shift;
   my @args = _normalize_input($self->{units},@_);
-  my($range,$bearing) = _inverse($self,@args);
+  my($range,$bearing) = $self->_inverse(@args);
   print "inverse(@_[1..4]) returns($range,$bearing)\n" if $DEBUG;
   return $range;
 }
 
+=pod
+
 =head2 bearing
 
 Returns the bearing in degrees or radians from the first location to
@@ -520,7 +545,7 @@ sub bearing
   my $self = shift;
   my $units = $self->{units};
   my @args = _normalize_input($units,@_);
-  my($range,$bearing) = _inverse($self,@args);
+  my($range,$bearing) = $self->_inverse(@args);
   print "inverse(@args) returns($range,$bearing)\n" if $DEBUG;
   my $t = $bearing;
   $self->_normalize_output('bearing',$bearing);
@@ -528,6 +553,7 @@ sub bearing
   return $bearing;
 }
 
+=pod
 
 =head2 at
 
@@ -545,13 +571,15 @@ sub at
   my( $lat, $lon, $az ) = _normalize_input($units,@_[0,1,3]);
   my $r = $_[2];
   print "at($lat,$lon,$r,$az)\n" if $DEBUG;
-  my( $lat2, $lon2 ) = _forward($self,$lat,$lon,$r,$az);
-  print "_forward returns ($lat2,$lon2)\n" if $DEBUG; 
+  my( $lat2, $lon2 ) = $self->_forward($lat,$lon,$r,$az);
+  print "_forward returns ($lat2,$lon2)\n" if $DEBUG;
   $self->_normalize_output('longitude',$lon2);
   $self->_normalize_output('latitude',$lat2);
-  return ( $lat2, $lon2 );  
+  return ( $lat2, $lon2 );
 }
 
+=pod
+
 =head2 to
 
 In list context, returns (range, bearing) between two specified locations.
@@ -568,7 +596,7 @@ sub to
   my $units = $self->{units};
   my @args = _normalize_input($units,@_);
   print "to($units,@args)\n" if $DEBUG;
-  my($range,$bearing) = _inverse($self,@args);
+  my($range,$bearing) = $self->_inverse(@args);
   print "to: inverse(@args) returns($range,$bearing)\n" if $DEBUG;
   #$bearing *= $degrees_per_radian if $units eq 'degrees';
   $self->_normalize_output('bearing',$bearing);
@@ -579,13 +607,15 @@ sub to
   }
 }
 
+=pod
+
 =head2 displacement
 
-Returns the (x,y) displacement in distance units between the two specified 
+Returns the (x,y) displacement in distance units between the two specified
 locations.
 
     my( $x, $y ) = $geo->displacement( $lat1, $lon1, $lat2, $lon2 );
-    
+
 NOTE: The x and y displacements are only approximations and only valid
 between two locations that are fairly near to each other. Beyond 10 kilometers
 or more, the concept of X and Y on a curved surface loses its meaning.
@@ -598,19 +628,21 @@ sub displacement
   print "displacement(",join(',',@_),"\n" if $DEBUG;
   my @args = _normalize_input($self->{units},@_);
   print "call _inverse(@args)\n" if $DEBUG;
-  my( $range, $bearing ) = _inverse($self,@args);
+  my( $range, $bearing ) = $self->_inverse(@args);
   print "disp: _inverse(@args) returns ($range,$bearing)\n" if $DEBUG;
   my $x = $range * sin($bearing);
   my $y = $range * cos($bearing);
   return ($x,$y);
 }
 
+=pod
+
 =head2 location
 
 Returns the list (latitude,longitude) of a location at a given (x,y)
 displacement from a given location.
 
-	my @loc = $geo->location( $lat, $lon, $x, $y );
+        my @loc = $geo->location( $lat, $lon, $x, $y );
 
 =cut
 
@@ -630,24 +662,24 @@ sub location
 #
 #      internal functions
 #
-#	inverse
+#       inverse
 #
-#	Calculate the displacement from origin to destination.
-#	The input to this subroutine is 
-#	  ( latitude-1, longitude-1, latitude-2, longitude-2 ) in radians.
+#       Calculate the displacement from origin to destination.
+#       The input to this subroutine is
+#         ( latitude-1, longitude-1, latitude-2, longitude-2 ) in radians.
 #
-#	Return the results as the list (range,bearing) with range in the
-#	current specified distance unit and bearing in radians.
+#       Return the results as the list (range,bearing) with range in the
+#       current specified distance unit and bearing in radians.
 
 sub _inverse()
 {
   my $self = shift;
   my( $lat1, $lon1, $lat2, $lon2 ) = (@_);
   print "_inverse($lat1,$lon1,$lat2,$lon2)\n" if $DEBUG;
-  
+
   my $a = $self->{equatorial};
   my $f = $self->{flattening};
-  
+
   my $r = 1.0 - $f;
   my $tu1 = $r * sin($lat1) / cos($lat1);
   my $tu2 = $r * sin($lat2) / cos($lat2);
@@ -658,14 +690,14 @@ sub _inverse()
   my $baz = $s * $tu2;
   my $faz = $baz * $tu1;
   my $dlon = $lon2 - $lon1;
-  
+
   if( $DEBUG ) {
-    printf "lat1=%.8f, lon1=%.8f\n", $lat1, $lon1; 
+    printf "lat1=%.8f, lon1=%.8f\n", $lat1, $lon1;
     printf "lat2=%.8f, lon2=%.8f\n", $lat2, $lon2;
     printf "r=%.8f, tu1=%.8f, tu2=%.8f\n", $r, $tu1, $tu2;
     printf "faz=%.8f, dlon=%.8f\n", $faz, $dlon;
   }
-  
+
   my $x = $dlon;
   my $cnt = 0;
   print "enter loop:\n" if $DEBUG;
@@ -676,10 +708,10 @@ sub _inverse()
     $cx = cos($x);
     $tu1 = $cu2*$sx;
     $tu2 = $baz - ($su1*$cu2*$cx);
-  
-    printf "    sx=%.8f, cx=%.8f, tu1=%.8f, tu2=%.8f\n", 
+
+    printf "    sx=%.8f, cx=%.8f, tu1=%.8f, tu2=%.8f\n",
       $sx, $cx, $tu1, $tu2 if $DEBUG;
-  
+
     $sy = sqrt( $tu1*$tu1 + $tu2*$tu2 );
     $cy = $s*$cx + $faz;
     $y = atan2($sy,$cy);
@@ -689,10 +721,10 @@ sub _inverse()
     }else{
       $sa = ($s*$sx) / $sy;
     }
-  
+
     printf "    sy=%.8f, cy=%.8f, y=%.8f, sa=%.8f\n", $sy, $cy, $y, $sa
       if $DEBUG;
-  
+
     $c2a = 1.0 - ($sa*$sa);
     $cz = $faz + $faz;
     if( $c2a > 0.0 ) {
@@ -704,15 +736,15 @@ sub _inverse()
     $x = ( ($e * $cy * $c + $cz) * $sy * $c + $y) * $sa;
     $x = ( 1.0 - $c ) * $x * $f + $dlon;
     $del = $d - $x;
-  
+
     if( $DEBUG ) {
       printf "    c2a=%.8f, cz=%.8f\n", $c2a, $cz;
       printf "    e=%.8f, d=%.8f\n", $e, $d;
       printf "    (d-x)=%.8g\n", $del;
     }
-  
+
   }while( (abs($del) > $eps) && ( ++$cnt <= $max_loop_count ) );
-  
+
   $faz = atan2($tu1,$tu2);
   $baz = atan2($cu1*$sx,($baz*$cx - $su1*$cu2)) + pi;
   $x = sqrt( ((1.0/($r*$r)) -1.0 ) * $c2a+1.0 ) + 1.0;
@@ -721,19 +753,19 @@ sub _inverse()
   $c = (($x*$x)/4.0 + 1.0)/$c;
   $d = ((0.375*$x*$x) - 1.0)*$x;
   $x = $e*$cy;
-  
+
   if( $DEBUG ) {
     printf "e=%.8f, cy=%.8f, x=%.8f\n", $e, $cy, $x;
     printf "sy=%.8f, c=%.8f, d=%.8f\n", $sy, $c, $d;
     printf "cz=%.8f, a=%.8f, r=%.8f\n", $cz, $a, $r;
   }
-  
+
   $s = 1.0 - $e - $e;
-  $s = (((((((( $sy * $sy * 4.0 ) - 3.0) * $s * $cz * $d/6.0) - $x) * 
+  $s = (((((((( $sy * $sy * 4.0 ) - 3.0) * $s * $cz * $d/6.0) - $x) *
     $d /4.0) + $cz) * $sy * $d) + $y ) * $c * $a * $r;
-  
+
   printf "s=%.8f\n", $s if $DEBUG;
-  
+
   # adjust azimuth to (0,360) or (-180,180) as specified
   if( $self->{symmetric} ) {
     $faz += $twopi if $faz < -(pi);
@@ -749,11 +781,11 @@ sub _inverse()
   return @disp;
 }
 
-#	_forward
+#       _forward
 #
-#	Calculate the location (latitue,longitude) of a point
-#	given a starting point and a displacement from that
-#	point as (range,bearing)
+#       Calculate the location (latitue,longitude) of a point
+#       given a starting point and a displacement from that
+#       point as (range,bearing)
 #
 sub _forward
 {
@@ -779,7 +811,7 @@ sub _forward
 
   my $baz = 0.0;
   $baz = 2.0 * atan2($tu,$cf) if( $cf != 0.0 );
-  
+
   my $cu = 1.0 / sqrt(1.0 + $tu*$tu);
   my $su = $tu * $cu;
   my $sa = $cu * $sf;
@@ -795,7 +827,7 @@ sub _forward
   if( $DEBUG ) {
     printf "r=%.8f, tu=%.8f, faz=%.8f\n", $r, $tu, $faz;
     printf "baz=%.8f, sf=%.8f, cf=%.8f\n", $baz, $sf, $cf;
-    printf "cu=%.8f, su=%.8f, sa=%.8f\n", $cu, $su, $sa; 
+    printf "cu=%.8f, su=%.8f, sa=%.8f\n", $cu, $su, $sa;
     printf "x=%.8f, c=%.8f, y=%.8f\n", $x, $c, $y;
   }
 
@@ -828,12 +860,12 @@ sub _forward
 
 }
 
-#	_normalize_input
+#       _normalize_input
 #
-#	Normalize a set of input angle values by converting to
-#	radians if given in degrees and by converting to the
-#	range [0,2pi), i.e. greater than or equal to zero and
-#	less than two pi.
+#       Normalize a set of input angle values by converting to
+#       radians if given in degrees and by converting to the
+#       range [0,2pi), i.e. greater than or equal to zero and
+#       less than two pi.
 #
 sub _normalize_input
 {
@@ -845,18 +877,18 @@ sub _normalize_input
     while( $_ >= $twopi ) { $_ -= $twopi }
     $_
   } @args;
-}  
+}
 
-#	_normalize_output
+#       _normalize_output
 #
-#	Normalize a set of output angle values by converting to
-#	degrees if needed and by converting to the range [-pi,+pi) or
-#	[0,2pi) as needed.
+#       Normalize a set of output angle values by converting to
+#       degrees if needed and by converting to the range [-pi,+pi) or
+#       [0,2pi) as needed.
 #
 sub _normalize_output
 {
   my $self = shift;
-  my $elem = shift;	# 'bearing' or 'longitude'
+  my $elem = shift;     # 'bearing' or 'longitude'
   # adjust remaining input values by reference
   for ( @_ ) {
     if( $self->{$elem} ) {
@@ -870,11 +902,13 @@ sub _normalize_output
     }
     $_ = rad2deg($_) if $self->{units} eq 'degrees';
   }
-}  
+}
+
+=pod
 
 =head1 DEFINED ELLIPSOIDS
 
-The following ellipsoids are defined in Geo::Ellipsoid, with the 
+The following ellipsoids are defined in Geo::Ellipsoid, with the
 semi-major axis in meters and the reciprocal flattening as shown.
 The default ellipsoid is WGS84.
 
@@ -938,6 +972,8 @@ L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Geo-Ellipsoid>.
 
 Copyright 2005-2008 Jim Gibson, all rights reserved.
 
+Copyright 2016 Peter John Acklam
+
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
